Method: Bio::Alignment::EnumerableExtension#alignment_normalize!

Defined in:
lib/bio/alignment.rb

#alignment_normalize!Object Also known as: normalize!

Fills gaps to the tail of each sequence if the length of the sequence is shorter than the alignment length.

Note that it is a destructive method.



712
713
714
715
716
717
718
719
# File 'lib/bio/alignment.rb', line 712

def alignment_normalize!
  #(original)
  len = alignment_length
  each_seq do |s|
    s << (gap_char * (len - s.length)) if s.length < len
  end
  self
end