Method: Bio::Sim4::Report::SegmentPair.both_intron

Defined in:
lib/bio/appl/sim4/report.rb

.both_intron(prev_e, e, aln) ⇒ Object

Parses part of sim4 result text and creates a new SegmentPair object for regions which can not be aligned correctly. It is designed to be called internally from Bio::Sim4::Report::Hit class. Users shall not use it directly.



206
207
208
209
210
# File 'lib/bio/appl/sim4/report.rb', line 206

def self.both_intron(prev_e, e, aln)
  self.new(Segment.new(prev_e.seq1.to+1, e.seq1.from-1, aln[0]),
           Segment.new(prev_e.seq2.to+1, e.seq2.from-1, aln[2]),
           aln[1])
end