Method: Bio::Fetch#databases
- Defined in:
- lib/bio/io/fetch.rb
#databases ⇒ Object
Using this method, the user can ask a dbfetch server what databases it supports. This would normally be the first step you’d take when you use a dbfetch server for the first time. Example:
server = Bio::Fetch.new()
puts server.databases # returns "aa aax bl cpd dgenes dr ec eg emb ..."
This method only works for the bioruby dbfetch server. For a list of databases available from the EBI, see the EBI website at www.ebi.ac.uk/cgi-bin/dbfetch/
- Returns
-
array of database names
143 144 145 |
# File 'lib/bio/io/fetch.rb', line 143 def databases _get_single('info', 'dbs').strip.split(/\s+/) end |